#
# spec file for package python3-pylast
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pylast
Version:        1.4.2
Release:        4.1
Summary:        A python3 interface to Last.fm
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/pylast/pylast
Source0:        https://pypi.python.org/packages/source/p/pylast/pylast-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
A python3 interface to Last.fm

Features:
- Simple public interface.
- Access to all the data exposed by the Last.fm webservices.
- Scrobbling support.
- Full object-oriented design.
- Proxy support.
- Internal caching support for some webservices calls (disabled by default).
- No extra dependencies but python itself.
- Support for other API-compatible networks like Libre.fm
- Python3-friendly (Starting from 0.5).

%prep
%setup -q -n pylast-%{version}

%build
python3 setup.py build

%install
python3 setup.py install -O1 --skip-build --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING
%dir %{python3_sitelib}/pylast
%{python3_sitelib}/pylast/*
%{python3_sitelib}/pylast-%{version}-py%{py3_ver}.egg-info

%changelog
* Sun Sep 27 2015 arun@gmx.de
- update to version 1.4.2
  * (no changelog available)
- changes from version 1.4.0:
  * Fix get_recent_tracks (and more)
- update to version 1.3.0:
  * Let Tox use these env vars
  * get_tagged_tracks: Use cacheable param
  * flake8
  * pep8 compliance
  * Add test case for Track.get_correction()
  * Add test case for Artist.get_correction()
  * Add suppport for track.getCorrection
  * Add suppport for artist.getCorrection
  * Fixed broken comment
  * User.GetPersonalTags bug fix
  * Added User.GetPersonalTags test cases
  * Fixed broken comment
  * Cleanup of User.GetPersonalTags stuff
  * Support for User.GetPersonalTags
  * Remove useless Scrutinizer badge
  * Replace broken pypip.in badges with shields.io
- changes from version 1.2.1:
  * Remember to release on master
  * Update release checklist
* Sun Aug 16 2015 zaitor@opensuse.org
- Add missing python3-six Requires.
* Sat May  9 2015 arun@gmx.de
- update to version 1.2.1 and 1.2.0:
  * Remove unused import
  * Remove artist.getImages and depracation note
  * Remove commented function
  * Retry failures up to four times, require at least one pass
  * Sometimes Last.fm returns an error for dates[1]: No chart available
  for this user/date-range combination
  * Add EditorConfig
  * Don't compare with limit if limit is None. Fixes #124.
  * Failing test for #124
  * 2015
  * Add licence
  * Don't redefine built-in
  * Remove unused argument
  * Badges: master -> develop, hugovk -> pylast
  * Run fast lint job first
  * Remove unused import
  * pep8 fixes
  * Rerun flaky interation tests
  * Release checklist
* Sun Jan 25 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed modname variable
  * updated source to point to pypi
  * require setuptools
  * no more README in tar-ball, removed it from %%files section
  * update %%files section
- update to version 1.1.0:
  * Fix pytest.py link
  * Update testing instructions [CI skip]
  * Remove unused .build file
  * fix grep filter for clonedigger.
  * remove dir-locals. make clonedigger always exit 0
  * fix base object hasing. Closes  #120 .
  * Version bump, fix setup.py, which was previously broken because excludes was not a tuple, so each character wa
  * Fix UnicodeDecodeError from #114. Replace definitions of _unicode and _string. Add six as a dependeny. Fix clo
  * Skip if PYLAST_USERNAME etc. env vars missing
  * Revert "Add failing test for #114" (This revert should be reverted later as the test from this commit should b
  * Remove duplicate line, Make test_pylast.py runnable as main again.
  * add credentials for IvanMalison/pylast.
  * Add failing test for #114
  * add posargs to tox tests.
  * Get rid of --doctest-modules in py.test command.
  * Consolidate travis environments. separate matrix and global environment variables.
  * Add tox to travis installation.
  * tox/travis stuff. making testing more uniform.
  * Don't encode strings as 'utf-8' twice in _get_cache_key. Closes #109.
  * Make pylast a package. Move tests into a directory. Start using pytest and tox. Use setuptools instead of dist
  * Remove unused import
  * Don't use .build file for minor version because we define the full version in pylast.py as well
  * Fix word in SessionKeyGenerator comment.
  * Fix params
  * Remove asserts which can fail
  * Landscape.io fixes
  * Add pypy3; track coverage in Scrutinizer
  * Use Docker
  * Update pylast.py
  * Make test more robust
  * Badges! [CI skip]
  * Add from/to parameters to get_recent_tracks()
  * Fix chart tests that failed due to date ranges (take 2)
  * Fix chart tests that failed due to date ranges
  * Last.fm returns no results for artist.getsimilar with limit=1, but limit=2 returns 2
  * Fix comparison with None for artist, album and event, with test. For #97.
  * Add artist.get_band_members() with tests
  * Add PyPI version badge
  * Add badge for number of PyPI downloads
  * syntax highlighting in readme
  * Fix opus comparison with None
  * Update install instructions now 1.0.0 is on PyPI
* Mon Aug  4 2014 p.drouand@gmail.com
- Remove conflict with python-pylast; it doesn't exist
* Mon Aug  4 2014 malcolmlewis@opensuse.org
- Initial build.
